pub struct WalletProperties {
pub network: Network,
pub fingerprint: Fingerprint,
pub server_pubkey: Option<PublicKey>,
}Expand description
Read-only properties of the Bark wallet.
Fields
network: NetworkThe Bitcoin network to run Bark on.
Default value: signet.
fingerprint: FingerprintThe wallet fingerpint
Used on wallet loading to check mnemonic correctness
server_pubkey: Option<PublicKey>The server public key from the initial connection.
This is used to detect if the Ark server has been replaced, which could indicate a malicious server. If the server pubkey changes, the wallet will refuse to connect and warn the user to perform an emergency exit.